@@ -654,7 +654,7 @@ class _CustomMLP(nn.Module):
             for idx in range(len(the_rest)-1):
                 layers.append(nn.Linear(the_rest[idx], the_rest[idx+1]))
                 if self.bn:
-                    layers.append(nn.BatchNorm1d(num_features=self.the_rest[idx+1]))
+                    layers.append(nn.BatchNorm1d(num_features=the_rest[idx+1]))
                 if activation_type == "tanh":
                     layers.append(nn.Tanh())
                 elif activation_type == "relu":
