@@ -78,6 +78,33 @@ class BaseProject:
         n_exps (int): Number of ``Experiemnt``s in ``exps``.
 
         pseudoexp (`Experiment`): Dummy ``Experiment`` for applying methods in ``Experiment``.
+    
+    Args:
+            
+        project_name (str): Name of the project. Directory of {path}/{project_name} will be created.
+
+        X (np.ndarray or torch.Tensor or pd.DataFrame): Data for the project. If X_test is not specified, X would be splitted(stratify=y) into train/val data with a given random state.
+
+        y (np.ndarray or torch.Tensor or pd.DataFrame): Labels for the project. If y_test is not specified, y would be splitted(stratify=y) into train/val labels with a given random state.
+
+        X_test (np.ndarray or torch.Tensor or pd.DataFrame, optional): Test data for the project. Specify this when there is a separate test data.
+            Default: ``None``
+
+        y_test (np.ndarray or torch.Tensor or pd.DataFrame, optional): Test labels for the project. Specify this when there is a separate test data.
+            Default: ``None``
+
+        n_classes (int): Number of classes for the classification task. Don't specify this when performing regression tasks.
+            Default: ``None``
+
+        stratify (bool): Whether to use label-stratification in splitting data into train/val/test set.
+            Default: ``True``
+        
+        path (str): Base path for the project. Default is the current directory.
+            Default: ``'.'``
+
+    Returns:
+
+        None
 
     """
 
@@ -92,36 +119,6 @@ class BaseProject:
         stratify : bool = True,
         path : str = "."
     )->None:
-        """Creates a ``Project``.
-
-        Args:
-            
-            project_name (str): Name of the project. Directory of {path}/{project_name} will be created.
-
-            X (np.ndarray or torch.Tensor or pd.DataFrame): Data for the project. If X_test is not specified, X would be splitted(stratify=y) into train/val data with a given random state.
-
-            y (np.ndarray or torch.Tensor or pd.DataFrame): Labels for the project. If y_test is not specified, y would be splitted(stratify=y) into train/val labels with a given random state.
-
-            X_test (np.ndarray or torch.Tensor or pd.DataFrame, optional): Test data for the project. Specify this when there is a separate test data.
-                Default: ``None``
-
-            y_test (np.ndarray or torch.Tensor or pd.DataFrame, optional): Test labels for the project. Specify this when there is a separate test data.
-                Default: ``None``
-
-            n_classes (int): Number of classes for the classification task. Don't specify this when performing regression tasks.
-                Default: ``None``
-
-            stratify (bool): Whether to use label-stratification in splitting data into train/val/test set.
-                Default: ``True``
-            
-            path (str): Base path for the project. Default is the current directory.
-                Default: ``'.'``
-
-        Returns:
-
-            None
-
-        """
         self.project_name = project_name
         self.X = X
         self.y = y
@@ -1048,6 +1045,29 @@ class Project(BaseProject):
         n_exps (int): Number of ``Experiemnt``s in ``exps``.
 
         pseudoexp (`Experiment`): Dummy ``Experiment`` for applying methods in ``Experiment``.
+    
+    Args:
+
+        project_name: Name of the project. Directory of {path}/{project_name} will be created.
+
+        X: Data for the project. If X_test is not specified, X would be splitted(stratify=y) into train/val data with a given random state.
+
+        y: Labels for the project. If y_test is not specified, y would be splitted(stratify=y) into train/val labels with a given random state.
+
+        X_test : Test data for the project. Specify this when there is a separate test data.
+            Default: ``None``
+
+        y_test : Test labels for the project. Specify this when there is a separate test data.
+            Default: ``None``
+
+        n_classes : Number of classes for the classification task. Don't specify this when performing regression tasks.
+            Default: ``None``
+        
+        stratify (bool): Whether to use label-stratification in splitting data into train/val/test set.
+            Default: ``True``
+        
+        path : Base path for the project. Default is the current directory.
+            Default: ``.``  
 
     """
     def __init__(
@@ -1061,32 +1081,6 @@ class Project(BaseProject):
         stratify : bool = True,
         path : str = "."
     )->None:
-        """
-        
-        Args:
-
-            project_name: Name of the project. Directory of {path}/{project_name} will be created.
-
-            X: Data for the project. If X_test is not specified, X would be splitted(stratify=y) into train/val data with a given random state.
-
-            y: Labels for the project. If y_test is not specified, y would be splitted(stratify=y) into train/val labels with a given random state.
-
-            X_test : Test data for the project. Specify this when there is a separate test data.
-                Default: ``None``
-
-            y_test : Test labels for the project. Specify this when there is a separate test data.
-                Default: ``None``
-
-            n_classes : Number of classes for the classification task. Don't specify this when performing regression tasks.
-                Default: ``None``
-            
-            stratify (bool): Whether to use label-stratification in splitting data into train/val/test set.
-                Default: ``True``
-            
-            path : Base path for the project. Default is the current directory.
-                Default: ``.``        
-
-        """
         super().__init__(
             project_name=project_name,
             X=X,
